*analyze_HERI.do
*This program creates all the exhibits for the paper

clear
clear mata
clear matrix
set matsize 11000 
set maxvar 10000

cap log close
log using "temp/stateU_analysis_log", replace
log off

*Table 3: baseline, 20k border-sides (3 col) and 20k distance bins(3 col)----------------------------------------------------
*--Part A: border-sides
*Note: locals below are for generating tables but I now hardcode table names and table notes
estimates clear
local bandwidth 20
local clustLev univBSide
local clustText "university-border_side"
local FE1 univYear
local FE2 borderSideYr
local ifCond private==0&year>1996

use "output/heri_analysis.dta", clear //acerecode-year-zipcode level, n=6,427,398
drop if distance>`bandwidth'|distance<-`bandwidth'
drop if (`ifCond')==0
collapse (sum) enroll_bsideYr=enroll_zipYear (mean) enroll_year inState tuition private, by(acerecode state_institution year border_ state_student state_border)
label variable enroll_bsideYr "enroll"
label variable inState "in-state"
egen borderSideYr=group(border_ state_student year) //this is a FE for the student side of border with institution state
egen univYear=group(acerecode year)
egen univBSide=group(acerecode border_ state_student)
*Drop university-border-years with only one side
egen uniq_UBSideYr=tag(acerecode year border_ state_student)
egen uniq_UBrdrYr=tag(acerecode year border_)
bysort acerecode year border_: egen numBSides=sum(uniq_UBSideYr)
tab numBSides if uniq_UBrdrYr
drop if numBSides!=2 //drops university-border-years with only one side, n=1434 for 20k
*Drop border-years with only one university
egen uniq_BSideYrU=tag(year border_ state_student acerecode)
bysort year border_ state_student: egen numU=sum(uniq_BSideYrU)
tab numU
drop if numU==1
*Generate dependent variables
gen lnN_bsideYr_p1=ln(enroll_bsideYr+1)
label variable lnN_bsideYr_p1 "ln(enroll)"
bysort acerecode border_ year: egen enroll_borderYr=sum(enroll_bsideYr)
gen perEnroll_bsideYr=enroll_bsideYr/enroll_borderYr //percentage of university's border enrollment from each side
label variable perEnroll_bsideYr "enroll(\%)"

*Now run regressions
*A
reg2hdfe enroll_bsideYr inState if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
*reghdfe enroll_bsideYr inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev') 
eststo N0
estadd local depvar "enroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*B
reg2hdfe perEnroll_bsideYr inState if `ifCond', id1(univYear) id2(borderSideYr) cluster(`clustLev')
*reghdfe perEnroll_bsideYr inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev') 
eststo perN0
estadd local depvar "perEnroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*C
reg2hdfe lnN_bsideYr_p1 inState if `ifCond', id1(univYear) id2(borderSideYr) cluster(`clustLev')
*reghdfe lnN_bsideYr_p1 inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev') 
eststo lnN0
estadd local depvar "lnN_bsideYr_p1", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*Output detailed table to log file for checking
log on
esttab N0 perN0 lnN0, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.4f) se(%6.4f) keep(inState) r2 label ///
scalars("t_FE1 FE level 1" "t_FE2 FE level 2" "df_r Residual df" "N_clust \#Clusters" "t_clust Cluster Level") ///
addnote("Regressions run at border\_side level for `bandwidth'k range." ///
"All specifications include univ-year and border\_side-year FE." ///
"Standard errors clustered at `clustText' level." ///
"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes
log off

*--Part B: DISTANCE-BINS--------------------------------------------------------------------
local bandwidth 20
local clustLev univBand
local clustText "university-band"
local tablename "distbins_20k.tex"
local FE1 univYear
local FE2 bandYear
local ifCond private==0&year>1996

use "output/heri_analysis.dta", clear //acerecode-year-zipcode level
drop if uniqUYrBand==0
drop if distance_b>(`bandwidth')|distance_b<-(`bandwidth') // sample is distance_b<21&distance_b>-21
drop if (`ifCond')==0
label variable enroll_bandYear "enroll"
label variable lnN_bandYear_p1 "ln(enroll)" //gen lnN_bandYear_p1=ln(enroll_bandYear+1)
*Drop university-border-years with only one side
egen uniq_UBSideYr=tag(acerecode year border_ state_student)
egen uniq_UBrdrYr=tag(acerecode year border_)
bysort acerecode year border_: egen numBSides=sum(uniq_UBSideYr)
tab numBSides if uniq_UBrdrYr
drop if numBSides!=2 //drops university-border-years with only one side
bysort acerecode border_ year: egen enroll_borderYr=sum(enroll_bandYear)
bysort acerecode year border_: egen numBands_UYr=sum(uniqUYrBand)
gen perEnroll_bandYr=(enroll_bandYear/enroll_borderYr)*(numBands_UYr/`bandwidth')
*gen perEnroll_bandYr=enroll_bandYear/enroll_borderYr //percentage of university's border enrollment in each band
label variable perEnroll_bandYr "enroll(\%)"

*A
*reg2hdfe enroll_bandYear inState distance_b if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe enroll_bandYear inState distance_b if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo N0_bin
estadd local depvar "enroll_bandYear", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*B
*reg2hdfe perEnroll_bandYr inState distance_b if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe perEnroll_bandYr inState distance_b if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo perN0_bin
estadd local depvar "perEnroll_bandYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*C
*reg2hdfe lnN_bandYear_p1 inState distance_b if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe lnN_bandYear_p1 inState distance_b if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo lnN0_bin
estadd local depvar "lnN_bandYear_p1", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*Output detailed table to log file for checking
log on
esttab N0_bin perN0_bin lnN0_bin, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.4f) se(%6.4f) keep(inState distance_b) r2 label ///
scalars("t_FE1 FE level 1" "t_FE2 FE level 2" "df_r Residual df" "N_clust \#Clusters" "t_clust Cluster Level") ///
addnote("Regressions run at distance-bin level; all specifications include university-year FE." ///
"Public universities only, 1997-2011, excludes twoyear colleges" ///
"Standard errors clustered at `clustText' level" ///
"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes
log off
*Look at estimates on screen
esttab N0 perN0 lnN0 N0_bin perN0_bin lnN0_bin, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.4f) se(%6.4f) keep(inState distance_b) ///
	r2 label mgroups("Border-sides" "Distance-bins", pattern(1 0 0 1 0 0) span)
*Output regression table to file for paper	
esttab N0 perN0 lnN0 N0_bin perN0_bin lnN0_bin using "exhibits\aej_t3.tex", replace starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.3f) se(%6.3f) ///
	keep(inState distance_b) r2 mtitles("enroll" "enroll(\%)" "ln(enroll)" "enroll" "enroll(\%)" "ln(enroll)") ///
	scalars("N_clust \#Clusters") sfmt(0) booktabs label mgroups("Border-sides" "Distance-bins", pattern(1 0 0 1 0 0) ///
	prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	addnote("Columns 1-3 at border-side level for 20km range; 4-6 at distance-bin level for 20km range." ///
		"All specifications include university-year FE and border-side-year or distance bin-year FE." ///
		"Sample is public universities, 1997-2011, excluding two-year colleges." ///
		"Standard errors clustered at university-border-side or university-distance-bin level" ///
		"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes

*Table 4: combine 20k border-side specification, public, above median students (old table 8) and "less-selective public institutions" old table 9
*Part A: public, above median students only, 20k--------------------------------------------------------------------
estimates clear
local bandwidth 20
local clustLev univBSide
local clustText "university-border_side"
local FE1 univYear
local FE2 borderSideYr
local ifCond private==0&year>1996

use "output/heri_analysis.dta", clear //acerecode-year-zipcode level
drop if distance>`bandwidth'|distance<-`bandwidth'
drop if (`ifCond')==0
collapse (sum) enroll_bsideYr=enroll_zipYear aboveMed_bsideYr=aboveMed_zipYear (mean) enroll_year inState tuition private, ///
	by(acerecode state_institution year border_ state_student state_border)
label variable aboveMed_bsideYr "enroll"
label variable inState "in-state"
*Drop university-border-years with only one side
egen uniq_UBSideYr=tag(acerecode year border_ state_student)
egen uniq_UBrdrYr=tag(acerecode year border_)
bysort acerecode year border_: egen numBSides=sum(uniq_UBSideYr)
tab numBSides if uniq_UBrdrYr
drop if numBSides!=2 //drops university-border-years with only one side, n=
*Generate dependent variables
gen lnN_abvMedBSYr_p1=ln(aboveMed_bsideYr+1)
label variable lnN_abvMedBSYr_p1 "ln(enroll)"
bysort acerecode border_ year: egen aboveMed_borderYr=sum(aboveMed_bsideYr)
gen per_aboveMed_bsideYr=aboveMed_bsideYr/aboveMed_borderYr //percentage of university's border enrollment from each side
label variable per_aboveMed_bsideYr "enroll(\%)"
egen borderSideYr=group(border_ state_student year) //this is a FE for the student side of border with institution state
egen univYear=group(acerecode year)
egen univBSide=group(acerecode border_ state_student)
*Now run regressions
*A
*reg2hdfe aboveMed_bsideYr inState if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe aboveMed_bsideYr inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo N0_abvmed
estadd local depvar "aboveMed_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*B
*reg2hdfe per_aboveMed_bsideYr inState if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe per_aboveMed_bsideYr inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo perN0_abvmed
estadd local depvar "per_aboveMed_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*C
*reg2hdfe lnN_abvMedBSYr_p1 inState if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe lnN_abvMedBSYr_p1 inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo lnN0_abvmed
estadd local depvar "lnN_abvMedBSYr_p1", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*Output detailed table to log file for checking
log on
esttab N0_abvmed perN0_abvmed lnN0_abvmed, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.4f) se(%6.4f) keep(inState) r2 label ///
scalars("t_FE1 FE level 1" "t_FE2 FE level 2" "df_r Residual df" "N_clust \#Clusters" "t_clust Cluster Level") ///
addnote("Regressions run at border-side level for `bandwidth'k range." ///
"All specifications include univ-year and border-side-year FE." ///
"Standard errors clustered at `clustText' level." ///
"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes
log off
*Part B: Less-selective universities, public, 20k--------------------------------------------------------------------
local bandwidth 20
local clustLev univBSide
local clustText "university-border_side"
local FE1 univYear
local FE2 borderSideYr
local ifCond selectU==0&private==0&year>1996

use "output/heri_analysis.dta", clear //acerecode-year-zipcode level
drop if private==1
gen tempScore=SAT_std_med if uniqUnivYr //n=3,265 unique PUBLIC university years with a median test score
bysort year: egen univMedScore=median(tempScore)
*br acerecode year tempScore univMedScore if tempScore!=.&year==1986
gen selectU=(SAT_std_med>univMedScore) if SAT_std_med!=.
drop tempScore

drop if distance>`bandwidth'|distance<-`bandwidth'
drop if (`ifCond')==0
collapse (sum) enroll_bsideYr=enroll_zipYear (mean) enroll_year inState tuition private selectU, by(acerecode state_institution year border_ state_student state_border)
label variable enroll_bsideYr "enroll"
label variable inState "in-state"
*Drop university-border-years with only one side
egen uniq_UBSideYr=tag(acerecode year border_ state_student)
egen uniq_UBrdrYr=tag(acerecode year border_)
bysort acerecode year border_: egen numBSides=sum(uniq_UBSideYr)
tab numBSides if uniq_UBrdrYr
drop if numBSides!=2 //drops university-border-years with only one side, n=
*Generate dependent variables
gen lnN_bsideYr_p1=ln(enroll_bsideYr+1)
label variable lnN_bsideYr_p1 "ln(enroll)"
bysort acerecode border_ year: egen enroll_borderYr=sum(enroll_bsideYr)
gen perEnroll_bsideYr=enroll_bsideYr/enroll_borderYr //percentage of university's border enrollment from each side
label variable perEnroll_bsideYr "enroll(\%)"
egen borderSideYr=group(border_ state_student year) //this is a FE for the student side of border with institution state
egen univYear=group(acerecode year)
egen univBSide=group(acerecode border_ state_student)
*Now run regressions
*A
*reg2hdfe enroll_bsideYr inState if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe enroll_bsideYr inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo N0_less
estadd local depvar "enroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*B
*reg2hdfe perEnroll_bsideYr inState if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe perEnroll_bsideYr inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo perN0_less
estadd local depvar "perEnroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*C
*reg2hdfe lnN_bsideYr_p1 inState if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe lnN_bsideYr_p1 inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo lnN0_less
estadd local depvar "lnN_bsideYr_p1", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*Output detailed table to log file for checking
log on
esttab N0_less perN0_less lnN0_less, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.3f) se(%6.3f) keep(inState) r2 label ///
scalars("t_FE1 FE level 1" "t_FE2 FE level 2" "df_r Residual df" "N_clust \#Clusters" "t_clust Cluster Level") ///
addnote("Regressions run at border-side level for `bandwidth'k range." ///
"All specifications include univ-year and border-side-year FE." ///
"Standard errors clustered at `clustText' level." ///
"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes
log off
*Look at estimates on screen
esttab N0_abvmed perN0_abvmed lnN0_abvmed N0_less perN0_less lnN0_less, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.3f) se(%6.3f) keep(inState) ///
	scalars("N_clust \#Clusters") sfmt(0) r2 label mgroups("Above median students" "Less selective institutions", pattern(1 0 0 1 0 0) span)
*Output regression table to file for paper	
esttab N0_abvmed perN0_abvmed lnN0_abvmed N0_less perN0_less lnN0_less using "exhibits\aej_t4.tex", replace starlevels(* 0.1 ** 0.05 *** 0.01) ///
	b(%6.3f) se(%6.3f) keep(inState) mtitles("enroll" "enroll(\%)" "ln(enroll)" "enroll" "enroll(\%)" "ln(enroll)")	///
	scalars("N_clust \#Clusters") sfmt(0) r2 booktabs label mgroups("Above median students" "Less selective institutions", pattern(1 0 0 1 0 0) ///
	prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	addnote("In columns 1-3 sample restricted to students with above median test score in university-year." ///
		"In columns 4-6 the sample restricted to less selective public universities." ///
		"All specifications include university-year FE and border-side-year FE; a border-side is 20km." ///
		"Sample is public universities, 1997-2011, excluding two-year colleges." ///
		"Standard errors clustered at university-border-side level" ///
		"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes
		
*Table 6: combine tuition (old table 10) and hybrid specification (old table 11); both are 20k bordersides
*Part A: Public, 20k, tuition specification--------------------------------------------------------------------
local bandwidth 20
local clustLev univBSide
local clustText "university-border_side"
local FE1 univYear
local FE2 borderSideYr
local ifCond private==0&year>1996
local indepVars tuition

use "output/heri_analysis.dta", clear //acerecode-year-zipcode level
drop if distance>`bandwidth'|distance<-`bandwidth'
drop if (`ifCond')==0
collapse (sum) enroll_bsideYr=enroll_zipYear (mean) enroll_year inState tuition private, by(acerecode state_institution year border_ state_student state_border)
label variable enroll_bsideYr "enroll"
label variable inState "in-state"
label variable tuition "tuition"
*Drop university-border-years with only one side
egen uniq_UBSideYr=tag(acerecode year border_ state_student)
egen uniq_UBrdrYr=tag(acerecode year border_)
bysort acerecode year border_: egen numBSides=sum(uniq_UBSideYr)
tab numBSides if uniq_UBrdrYr
drop if numBSides!=2 //drops university-border-years with only one side, n=
*Generate dependent variables
gen lnN_bsideYr_p1=ln(enroll_bsideYr+1)
label variable lnN_bsideYr_p1 "ln(enroll)"
bysort acerecode border_ year: egen enroll_borderYr=sum(enroll_bsideYr)
gen perEnroll_bsideYr=enroll_bsideYr/enroll_borderYr //percentage of university's border enrollment from each side
label variable perEnroll_bsideYr "enroll(\%)"
egen borderSideYr=group(border_ state_student year) //this is a FE for the student side of border with institution state
egen univYear=group(acerecode year)
egen univBSide=group(acerecode border_ state_student)
*Now run regressions
*A
*reg2hdfe enroll_bsideYr `indepVars' if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe enroll_bsideYr `indepVars' if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo N0_tuit
estadd local depvar "enroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*B
*reg2hdfe perEnroll_bsideYr `indepVars' if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe perEnroll_bsideYr `indepVars' if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo perN0_tuit
estadd local depvar "perEnroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*C
*reg2hdfe lnN_bsideYr_p1 `indepVars' if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe lnN_bsideYr_p1 `indepVars' if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo lnN0_tuit
estadd local depvar "lnN_bsideYr_p1", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*Output detailed table to log file for checking
log on
esttab N0_tuit perN0_tuit lnN0_tuit, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.4f) se(%6.4f) keep(`indepVars') r2 label ///
scalars("t_FE1 FE level 1" "t_FE2 FE level 2" "df_r Residual df" "N_clust \#Clusters" "t_clust Cluster Level") ///
addnote("Regressions run at border\_side level for `bandwidth'k range." ///
"All specifications include univ-year and border\_side-year FE." ///
"Standard errors clustered at `clustText' level." ///
"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes
log off
*B: Public, 20k, hybrid specification--------------------------------------------------------------------
local bandwidth 20
local clustLev univBSide
local clustText "university-border_side"
local FE1 univYear
local FE2 borderSideYr
local ifCond private==0&year>1996
local indepVars inState tuition

use "output/heri_analysis.dta", clear //acerecode-year-zipcode level
drop if distance>`bandwidth'|distance<-`bandwidth'
drop if (`ifCond')==0
collapse (sum) enroll_bsideYr=enroll_zipYear (mean) enroll_year inState tuition private, by(acerecode state_institution year border_ state_student state_border)
label variable enroll_bsideYr "enroll"
label variable inState "in-state"
label variable tuition "tuition"
*Drop university-border-years with only one side
egen uniq_UBSideYr=tag(acerecode year border_ state_student)
egen uniq_UBrdrYr=tag(acerecode year border_)
bysort acerecode year border_: egen numBSides=sum(uniq_UBSideYr)
tab numBSides if uniq_UBrdrYr
drop if numBSides!=2 //drops university-border-years with only one side, n=
*Generate dependent variables
gen lnN_bsideYr_p1=ln(enroll_bsideYr+1)
label variable lnN_bsideYr_p1 "ln(enroll)"
bysort acerecode border_ year: egen enroll_borderYr=sum(enroll_bsideYr)
gen perEnroll_bsideYr=enroll_bsideYr/enroll_borderYr //percentage of university's border enrollment from each side
label variable perEnroll_bsideYr "enroll(\%)"
egen borderSideYr=group(border_ state_student year) //this is a FE for the student side of border with institution state
egen univYear=group(acerecode year)
egen univBSide=group(acerecode border_ state_student)
*Now run regressions
*A
*reg2hdfe enroll_bsideYr `indepVars' if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe enroll_bsideYr `indepVars' if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo N0_hybrid
estadd local depvar "enroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*B
*reg2hdfe perEnroll_bsideYr `indepVars' if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe perEnroll_bsideYr `indepVars' if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo perN0_hybrid
estadd local depvar "perEnroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*C
*reg2hdfe lnN_bsideYr_p1 `indepVars' if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe lnN_bsideYr_p1 `indepVars' if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo lnN0_hybrid
estadd local depvar "lnN_bsideYr_p1", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*Output detailed table to log file for checking
log on
esttab N0_hybrid perN0_hybrid lnN0_hybrid, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.4f) se(%6.4f) keep(`indepVars') r2 label ///
scalars("t_FE1 FE level 1" "t_FE2 FE level 2" "df_r Residual df" "N_clust \#Clusters" "t_clust Cluster Level") ///
addnote("Regressions run at border\_side level for `bandwidth'k range." ///
"All specifications include univ-year and border\_side-year FE." ///
"Standard errors clustered at `clustText' level." ///
"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes
log off
*Look at estimates on screen
esttab N0_tuit perN0_tuit lnN0_tuit N0_hybrid perN0_hybrid lnN0_hybrid, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.3f) se(%6.3f) keep(inState tuition) ///
	scalars("N_clust \#Clusters") sfmt(0) r2 label mgroups("Tuition Specification" "Hybrid Specification", pattern(1 0 0 1 0 0) span)
*Output regression table to file for paper	
esttab N0_tuit perN0_tuit lnN0_tuit N0_hybrid perN0_hybrid lnN0_hybrid using "exhibits\aej_t6.tex", replace starlevels(* 0.1 ** 0.05 *** 0.01) ///
	b(%6.3f) se(%6.3f) keep(inState tuition) mtitles("enroll" "enroll(\%)" "ln(enroll)" "enroll" "enroll(\%)" "ln(enroll)")	///
	scalars("N_clust \#Clusters") sfmt(0) r2 booktabs label mgroups("Tuition Specification" "Hybrid Specification", pattern(1 0 0 1 0 0) ///
	prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	addnote("All specifications include university-year FE and border-side-year FE; a border-side is 20km." ///
		"Sample is public universities, 1997-2011, excluding two-year colleges." ///
		"Standard errors clustered at university-border-side level" ///
		"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes
		
*Table 7: TUITION EXCHANGE, 20k------------------------------------------------
local bandwidth 20
local clustLev univBSide
local clustText "university-border_side"
local FE1 univYear
local FE2 borderSideYr
local ifCond private==0&year>1996

use "output/heri_analysis.dta", clear //acerecode-year-zipcode level
drop if distance>`bandwidth'|distance<-`bandwidth'
drop if (`ifCond')==0
*Generate tuition exchange interaction

gen in_exchange=0
foreach grp in MSEP NEBHE SREB WUE {
	replace in_exchange=1 if (univ_`grp'==stud_`grp')&(stud_`grp'==1)&(state_institution!=state_student) //excludes in-state obs
}
bysort border_ year: egen tempExchange=max(in_exchange)
replace in_exchange=tempExchange
gen exchange_name=""
foreach grp in MSEP NEBHE SREB WUE {
	replace exchange_name="`grp'" if in_exchange==1&(univ_`grp'==stud_`grp')&(stud_`grp'==1)
}
drop tempExchange
gen inState_exchange=in_exchange*inState

collapse (sum) enroll_bsideYr=enroll_zipYear (mean) enroll_year inState inState_exchange in_exchange tuition private, by(acerecode state_institution year border_ state_student state_border exchange_name)
label variable enroll_bsideYr "enroll"
label variable inState "in-state"
label variable inState_exchange "in-state X exchange"
egen borderSideYr=group(border_ state_student year) //this is a FE for the student side of border with institution state
egen univYear=group(acerecode year)
egen univBSide=group(acerecode border_ state_student)
*Drop university-border-years with only one side
egen uniq_UBSideYr=tag(acerecode year border_ state_student)
egen uniq_UBrdrYr=tag(acerecode year border_)
bysort acerecode year border_: egen numBSides=sum(uniq_UBSideYr)
tab numBSides if uniq_UBrdrYr
drop if numBSides!=2 //drops university-border-years with only one side, n=1434 for 20k
*Drop border-years with only one university
egen uniq_BSideYrU=tag(year border_ state_student acerecode)
bysort year border_ state_student: egen numU=sum(uniq_BSideYrU)
tab numU
drop if numU==1
*Generate dependent variables
gen lnN_bsideYr_p1=ln(enroll_bsideYr+1)
label variable lnN_bsideYr_p1 "ln(enroll)"
bysort acerecode border_ year: egen enroll_borderYr=sum(enroll_bsideYr)
gen perEnroll_bsideYr=enroll_bsideYr/enroll_borderYr //percentage of university's border enrollment from each side
label variable perEnroll_bsideYr "enroll(\%)"
*Now run regressions
*A
*reg2hdfe enroll_bsideYr inState inState_exchange if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe enroll_bsideYr inState inState_exchange if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo N0_exchg
estadd local depvar "enroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*B
*reg2hdfe perEnroll_bsideYr inState inState_exchange if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe perEnroll_bsideYr inState inState_exchange if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo perN0_exchg
estadd local depvar "perEnroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*C
*reg2hdfe lnN_bsideYr_p1 inState inState_exchange if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe lnN_bsideYr_p1 inState inState_exchange if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo lnN0_exchg
estadd local depvar "lnN_bsideYr_p1", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"

log on
esttab N0_exchg perN0_exchg lnN0_exchg, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.4f) se(%6.4f) keep(inState inState_exchange) r2 label ///
scalars("t_FE1 FE level 1" "t_FE2 FE level 2" "df_r Residual df" "N_clust \#Clusters" "t_clust Cluster Level") ///
addnote("Regressions run at border-side level for `bandwidth'k range." ///
"All specifications include univ-year and border-side-year FE." ///
"Standard errors clustered at `clustText' level." ///
"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes
log off

esttab N0_exchg perN0_exchg lnN0_exchg using "exhibits\aej_t7.tex", replace starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.3f) se(%6.3f) ///
	keep(inState inState_exchange) r2 label booktabs scalars("N_clust \#Clusters") sfmt(0) ///
	addnote("Regressions run at border-side level for 20km range." ///
	"Sample is public universities only, 1997-2011;" ///
	"two-year colleges are excluded." ///
	"All specifications include univ-year and border-side-year FE." ///
	"Standard errors clustered at university-border-side level." ///
	"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes		
		
*Table 5: Public and Private specification
local bandwidth 20
local clustLev univBSide
local clustText "university-border_side"
local FE1 univYear
local FE2 borderSideYr
local ifCond year>1996 //I include both public and private so that I can do difference analysis

use "output/heri_analysis.dta", clear //acerecode-year-zipcode level, n=6,427,398
drop if distance>`bandwidth'|distance<-`bandwidth'
drop if (`ifCond')==0
collapse (sum) enroll_bsideYr=enroll_zipYear (mean) enroll_year inState tuition private, by(acerecode state_institution year border_ state_student state_border)
label variable enroll_bsideYr "enroll"
label variable inState "in-state"
egen borderSideYr=group(border_ state_student year) //this is a FE for the student side of border with institution state
egen univYear=group(acerecode year)
egen univBSide=group(acerecode border_ state_student)
*Drop university-border-years with only one side
egen uniq_UBSideYr=tag(acerecode year border_ state_student)
egen uniq_UBrdrYr=tag(acerecode year border_)
bysort acerecode year border_: egen numBSides=sum(uniq_UBSideYr)
tab numBSides if uniq_UBrdrYr
drop if numBSides!=2 //drops university-border-years with only one side, n=1434 for 20k
*Drop border-years with only one university
egen uniq_BSideYrU=tag(year border_ state_student acerecode)
bysort year border_ state_student: egen numU=sum(uniq_BSideYrU)
tab numU
drop if numU==1
*Generate dependent variables
gen lnN_bsideYr_p1=ln(enroll_bsideYr+1)
label variable lnN_bsideYr_p1 "ln(enroll)"
bysort acerecode border_ year: egen enroll_borderYr=sum(enroll_bsideYr)
gen perEnroll_bsideYr=enroll_bsideYr/enroll_borderYr //percentage of university's border enrollment from each side
label variable perEnroll_bsideYr "enroll(\%)"
*Create DiD Regression table with all three depvars: levels, percent, logs
gen inStatePublic=(inState==1&private==0)
label variable inStatePublic "in-state X public"
*A
reghdfe enroll_bsideYr inState inStatePublic if year>1996&private!=., absorb(univYear borderSideYr) cluster(univBSide)
eststo N0_privpub
estadd local depvar "enroll_bsideYr", replace
*B
reghdfe perEnroll_bsideYr inState inStatePublic if year>1996&private!=., absorb(univYear borderSideYr) cluster(univBSide)
eststo perN0_privpub
estadd local depvar "perEnroll_bsideYr", replace
*C
reghdfe lnN_bsideYr_p1 inState inStatePublic if year>1996&private!=., absorb(univYear borderSideYr) cluster(univBSide)
eststo lnN0_privpub
estadd local depvar "lnN_bsideYr_p1", replace

esttab N0_privpub perN0_privpub lnN0_privpub, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.3f) se(%6.3f) keep(inState inStatePublic) r2 label scalars("N_clust \#Clusters") sfmt(0)
*Output regression table to file for paper
esttab N0_privpub perN0_privpub lnN0_privpub using "exhibits\aej_t5.tex", replace starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.3f) se(%6.3f) ///
	keep(inState inStatePublic) r2 label booktabs scalars("N_clust \#Clusters") sfmt(0) ///
	addnote("Regressions run at border-side level for 20km range." ///
	"Sample includes public and private universities, 1997-2011;" ///
	"two-year colleges are excluded." ///
	"All specifications include univ-year and border-side-year FE." ///
	"Standard errors clustered at university-border-side level." ///
	"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes
	
*ONLINE APPENDIX TABLES---------------------------------------------------------
*Appendix Table B3: show 10k and 30k estimates
*A: baseline, 10k--------------------------------------------------------------------
local bandwidth 10
local clustLev univBSide
local clustText "university-border_side"
local FE1 univYear
local FE2 borderSideYr
local ifCond private==0&year>1996

use "output/heri_analysis.dta", clear //acerecode-year-zipcode level
drop if distance>`bandwidth'|distance<-`bandwidth'
drop if (`ifCond')==0
collapse (sum) enroll_bsideYr=enroll_zipYear (mean) enroll_year inState tuition private, by(acerecode state_institution year border_ state_student state_border)
label variable enroll_bsideYr "enroll"
label variable inState "in-state"
*Drop university-border-years with only one side
egen uniq_UBSideYr=tag(acerecode year border_ state_student)
egen uniq_UBrdrYr=tag(acerecode year border_)
bysort acerecode year border_: egen numBSides=sum(uniq_UBSideYr)
tab numBSides if uniq_UBrdrYr
drop if numBSides!=2 //drops university-border-years with only one side, n=2432 for 10k
*Generate dependent variables
gen lnN_bsideYr_p1=ln(enroll_bsideYr+1)
label variable lnN_bsideYr_p1 "ln(enroll)"
bysort acerecode border_ year: egen enroll_borderYr=sum(enroll_bsideYr)
gen perEnroll_bsideYr=enroll_bsideYr/enroll_borderYr //percentage of university's border enrollment from each side
label variable perEnroll_bsideYr "enroll(\%)"
egen borderSideYr=group(border_ state_student year) //this is a FE for the student side of border with institution state
egen univYear=group(acerecode year)
egen univBSide=group(acerecode border_ state_student)
*Now run regressions
*A
*reg2hdfe enroll_bsideYr inState if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe enroll_bsideYr inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo N0_10k
estadd local depvar "enroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*B
*reg2hdfe perEnroll_bsideYr inState if `ifCond', id1(univYear) id2(borderSideYr) cluster(`clustLev')
reghdfe perEnroll_bsideYr inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo perN0_10k
estadd local depvar "perEnroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*C
*reg2hdfe lnN_bsideYr_p1 inState if `ifCond', id1(univYear) id2(borderSideYr) cluster(`clustLev')
reghdfe lnN_bsideYr_p1 inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo lnN0_10k
estadd local depvar "lnN_bsideYr_p1", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*Output detailed table to log file for checking
log on
esttab N0_10k perN0_10k lnN0_10k, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.4f) se(%6.4f) keep(inState) r2 label ///
scalars("t_FE1 FE level 1" "t_FE2 FE level 2" "df_r Residual df" "N_clust \#Clusters" "t_clust Cluster Level") ///
addnote("Regressions run at border\_side level for `bandwidth'k range." ///
"All specifications include univ-year and border\_side-year FE." ///
"Standard errors clustered at `clustText' level." ///
"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes
log off
*B: baseline 30k--------------------------------------------------------------------
local bandwidth 30
local clustLev univBSide
local clustText "university-border_side"
local FE1 univYear
local FE2 borderSideYr
local ifCond private==0&year>1996

use "output/heri_analysis.dta", clear //acerecode-year-zipcode level
drop if distance>`bandwidth'|distance<-`bandwidth'
drop if (`ifCond')==0
collapse (sum) enroll_bsideYr=enroll_zipYear (mean) enroll_year inState tuition private, by(acerecode state_institution year border_ state_student state_border)
label variable enroll_bsideYr "enroll"
label variable inState "in-state"
*Drop university-border-years with only one side
egen uniq_UBSideYr=tag(acerecode year border_ state_student)
egen uniq_UBrdrYr=tag(acerecode year border_)
bysort acerecode year border_: egen numBSides=sum(uniq_UBSideYr)
tab numBSides if uniq_UBrdrYr
drop if numBSides!=2 //drops university-border-years with only one side, n=1713 for 30k
*Generate dependent variables
gen lnN_bsideYr_p1=ln(enroll_bsideYr+1)
label variable lnN_bsideYr_p1 "ln(enroll)"
bysort acerecode border_ year: egen enroll_borderYr=sum(enroll_bsideYr)
gen perEnroll_bsideYr=enroll_bsideYr/enroll_borderYr //percentage of university's border enrollment from each side
label variable perEnroll_bsideYr "enroll(\%)"
egen borderSideYr=group(border_ state_student year) //this is a FE for the student side of border with institution state
egen univYear=group(acerecode year)
egen univBSide=group(acerecode border_ state_student)
*Now run regressions
*A
*reg2hdfe enroll_bsideYr inState if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe enroll_bsideYr inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo N0_30k
estadd local depvar "enroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*B
*reg2hdfe perEnroll_bsideYr inState if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe perEnroll_bsideYr inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo perN0_30k
estadd local depvar "perEnroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*C
*reg2hdfe lnN_bsideYr_p1 inState if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe lnN_bsideYr_p1 inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo lnN0_30k
estadd local depvar "lnN_bsideYr_p1", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
*Output detailed table to log file for checking
log on
esttab N0_30k perN0_30k lnN0_30k, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.4f) se(%6.4f) keep(inState) r2 label ///
scalars("t_FE1 FE level 1" "t_FE2 FE level 2" "df_r Residual df" "N_clust \#Clusters" "t_clust Cluster Level") ///
addnote("Regressions run at border\_side level for `bandwidth'k range." ///
"All specifications include univ-year and border\_side-year FE." ///
"Standard errors clustered at `clustText' level." ///
"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes
log off
esttab N0_10k perN0_10k lnN0_10k N0_30k perN0_30k lnN0_30k, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.3f) se(%6.3f) ///
	keep(inState) r2 mtitles("enroll" "enroll(\%)" "ln(enroll)" "enroll" "enroll(\%)" "ln(enroll)") ///
	scalars("N_clust \#Clusters") sfmt(0) label mgroups("10km borders" "30km borders", pattern(1 0 0 1 0 0))
*Output regression table to file for paper
esttab N0_10k perN0_10k lnN0_10k N0_30k perN0_30k lnN0_30k using "exhibits\aej_b3.tex", replace starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.3f) se(%6.3f) ///
	keep(inState) r2 mtitles("enroll" "enroll(\%)" "ln(enroll)" "enroll" "enroll(\%)" "ln(enroll)") ///
	scalars("N_clust \#Clusters") sfmt(0) booktabs label mgroups("10km border-sides" "30km border-sides", pattern(1 0 0 1 0 0) ///
	prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	addnote("Columns 1-3 at border-side level for 10km border-sides, cols 4-6 use 30km border-sides." ///
		"All specifications include university-year FE and border-side-year FE." ///
		"Sample is public universities, 1997-2011, excluding two-year colleges." ///
		"Standard errors clustered at university-border-side level" ///
		"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes

*Appendix Table ##: DROPPING BORDER UNIVERSITIES WITHIN 30K---------------------
local bandwidth 20
local clustLev univBSide
local clustText "university-border_side"
local FE1 univYear
local FE2 borderSideYr
local ifCond private==0&year>1996
local excl_dist=30

use "output/heri_analysis.dta", clear //acerecode-year-zipcode level
drop if distance>`bandwidth'|distance<-`bandwidth'
drop if inst_borderDist<=`excl_dist'&inst_borderDist!=. //inst_borderDist has university to border dist
collapse (sum) enroll_bsideYr=enroll_zipYear (mean) enroll_year inState tuition private, ///
	by(acerecode state_institution year border_ state_student state_border inst_borderDist) 
label variable enroll_bsideYr "enroll"
label variable inState "in-state"
egen borderSideYr=group(border_ state_student year) //this is a FE for the student side of border with institution state
egen univYear=group(acerecode year)
egen univBSide=group(acerecode border_ state_student)
*Drop university-border-years with only one side
egen uniq_UBSideYr=tag(acerecode year border_ state_student)
egen uniq_UBrdrYr=tag(acerecode year border_)
bysort acerecode year border_: egen numBSides=sum(uniq_UBSideYr)
tab numBSides if uniq_UBrdrYr
drop if numBSides!=2 //drops university-border-years with only one side, n=1434 for 20k
*Drop border-years with only one university
egen uniq_BSideYrU=tag(year border_ state_student acerecode)
bysort year border_ state_student: egen numU=sum(uniq_BSideYrU)
tab numU
drop if numU==1
*Generate dependent variables
gen lnN_bsideYr_p1=ln(enroll_bsideYr+1)
label variable lnN_bsideYr_p1 "ln(enroll)"
bysort acerecode border_ year: egen enroll_borderYr=sum(enroll_bsideYr)
gen perEnroll_bsideYr=enroll_bsideYr/enroll_borderYr //percentage of university's border enrollment from each side
label variable perEnroll_bsideYr "enroll(\%)"

*Now run regressions
*A
*reg2hdfe enroll_bsideYr inState if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe enroll_bsideYr inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo N0_nobrd
estadd local depvar "enroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
estadd local excl "`excl_dist'"
*B
*reg2hdfe perEnroll_bsideYr inState if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe perEnroll_bsideYr inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo perN0_nobrd
estadd local depvar "perEnroll_bsideYr", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
estadd local excl "`excl_dist'"
*C
*reg2hdfe lnN_bsideYr_p1 inState if `ifCond', id1(`FE1') id2(`FE2') cluster(`clustLev')
reghdfe lnN_bsideYr_p1 inState if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
eststo lnN0_nobrd
estadd local depvar "lnN_bsideYr_p1", replace
estadd local t_FE1 "`FE1'"
estadd local t_FE2 "`FE2'"
estadd local t_clust "`clustLev'"
estadd local excl "`excl_dist'"

esttab N0_nobrd perN0_nobrd lnN0_nobrd, starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.4f) se(%6.4f) keep(inState) r2 label ///
scalars("t_FE1 FE level 1" "t_FE2 FE level 2" "df_r Residual df" "N_clust \#Clusters" "t_clust Cluster Level" "excl Exclude Dist") ///
addnote("Regressions run at border\_side level for `bandwidth'k range." ///
"All specifications include univ-year and border\_side-year FE." ///
"Standard errors clustered at `clustText' level." ///
"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes

*Output regression table to file for paper
esttab N0_nobrd perN0_nobrd lnN0_nobrd using "exhibits\aej_b4.tex", replace starlevels(* 0.1 ** 0.05 *** 0.01) b(%6.3f) se(%6.3f) keep(inState) r2 label ///
	scalars("N_clust \#Clusters") sfmt(0) booktabs addnote("Regressions run at border-side level, 20km border-sides." ///
	"Sample is public universities only, 1997-2011;" ///
	"two-year colleges are excluded." ///
	"Sample also drops universities within 30km of border." ///
	"All specifications include univ-year and border-side-year FE." ///
	"Standard errors clustered at university-border-side level." ///
	"* p$<$0.1 ** p$<$0.05 *** p$<$0.01") nonotes

*Figures------------------------------------------------------------------------
local bandwidth 20
local clustLev univBand
local FE1 univYear
local FE2 bandYear
local ifCond private==0&year>1996

use "output/heri_analysis.dta", clear //acerecode-year-zipcode level
drop if distance_b>`bandwidth'|distance_b<-`bandwidth'
drop enroll_borderYear //confusing--this is based on the entire border
bysort acerecode year border_: egen enroll_borderYr=sum(enroll_zipYear) //same as if aggregate enroll_bandYear by unique univ-yr-band
*Drop university-border-years with only one side
egen uniq_UBSideYr=tag(acerecode year border_ state_student)
bysort acerecode year border_: egen numBSides=sum(uniq_UBSideYr)
egen uniq_UBrdrYr=tag(acerecode year border_)
tab numBSides if uniq_UBrdrYr
drop if numBSides!=2 //drops university-border-years with only one side, n=
bysort acerecode year border_: egen numBands_UYr=sum(uniqUYrBand)
gen perEnroll_bandYear=(enroll_bandYear/enroll_borderYr)*(numBands_UYr/`bandwidth')
drop if uniqUYrBand==0
*Run regression so that sample size in graph matches regression sample
reghdfe enroll_bandYear inState distance_b if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
count if e(sample)
local grSamp=r(N)

*Figure 3) Raw enrollment (count), Public, 1997-2011
*local ifCond distance_b<=`bandwidth'&distance_b>=-`bandwidth'&private==0&year>1996&uniqUYrBand
graph bar (mean) enroll_bandYear if e(sample), over(distance_b, label(labsize(small))) ytitle("Count students") ///
title("Public: # students by distance bin from border") note("Y-variable is annual enrollment from each university, averaged across public universities." ///
"This average is done for all years 1997-2011, by distance bin (2km)." ///
"Sample size is  n=`grSamp'.") name(countDist, replace) graphregion(color(white))
gr export "exhibits\aej_fig3.pdf", replace

*Figure 4) Percentage enrollment (count), Public, 1997-2011
local bandwidth 20
local clustLev univBand
local FE1 univYear
local FE2 bandYear
local ifCond private==0&year>1996
*local ifCond distance_b<=`bandwidth'&distance_b>=-`bandwidth'&private==0&year>1996&uniqUYrBand
*Check sum of percentage bars: hopefully these are close to one
gen temp=perEnroll_bandYear if `ifCond'
bysort distance_b: egen checkSum=mean(temp)
egen uniq_dist=tag(distance_b)
sum checkSum if uniq_dist
display "This should be 1; actual result is " as result r(sum)
br checkSum distance_b if uniq_dist
drop uniq_dist temp checkSum

reghdfe perEnroll_bandYear inState distance_b if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
count if e(sample)
local grSamp=r(N)
graph bar (mean) perEnroll_bandYear if e(sample), over(distance_b, label(labsize(small))) ytitle("Percentage from each bin") ///
yscale(range(0 0.10)) ylabel(0(0.02)0.1) graphregion(color(white)) ///
title("Public: % enrollment by distance bin from border") note("Y-variable is percentage of a university's annual border enrollment from bin," ///
"averaged across public universities, all years 1997-2011, within a distance bin (2km)." ///
"Borders with fewer than 20 distance bins scaled by bin count. Sample size: n=`grSamp'.") name(perDist, replace)
gr export "exhibits\aej_fig4.pdf", replace

*Figure 5) Raw enrollment (count), PRIVATE, 1997-2011
local bandwidth 20
local clustLev univBand
local FE1 univYear
local FE2 bandYear
local ifCond private==1&year>1996
reghdfe enroll_bandYear inState distance_b if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
count if e(sample)
local grSamp=r(N)
graph bar (mean) enroll_bandYear if e(sample), over(distance_b, label(labsize(small))) ytitle("Count students") graphregion(color(white)) ///
title("Private: # students by distance bin from border") note("Y-variable is annual enrollment from each university, averaged across private universities." ///
"This average is done for all years 1997-2011, in distance bin (2km)." ///
"Sample size is  n=`grSamp'.") name(countDist, replace)
gr export "exhibits\aej_fig5.pdf", replace

*Figure 6) Percentage enrollment (count), PRIVATE, 1997-2011
local bandwidth 20
local clustLev univBand
local FE1 univYear
local FE2 bandYear
local ifCond private==1&year>1996
*local ifCond distance_b<=`bandwidth'&distance_b>=-`bandwidth'&private==1&year>1996&uniqUYrBand
*Check sum of percentage bars: hopefully these are close to one
gen temp=perEnroll_bandYear if `ifCond'
bysort distance_b: egen checkSum=mean(temp)
egen uniq_dist=tag(distance_b)
sum checkSum if uniq_dist
display "This should be 1:" as result r(mean)*r(N)
br checkSum distance_b if uniq_dist
drop uniq_dist temp checkSum

reghdfe perEnroll_bandYear inState distance_b if `ifCond', absorb(`FE1' `FE2') cluster(`clustLev')
count if e(sample)
local grSamp=r(N)
graph bar (mean) perEnroll_bandYear if e(sample), over(distance_b, label(labsize(small))) ytitle("Percentage from each bin") ///
yscale(range(0 0.10)) ylabel(0(0.02)0.1) graphregion(color(white)) ///
title("Private: % enrollment by distance bin from border") note("Y-variable is percentage of a university's annual border enrollment from bin," ///
"averaged across private universities, all years 1997-2011, within a distance bin (2km)." ///
"Borders with fewer than 20 distance bins scaled by bin count. Sample size: n=`grSamp'.") name(perDist, replace)
gr export "exhibits\aej_fig6.pdf", replace
