*create_analysis_file.DO
*This program builds the file used in the discontinuity analysis

*Section 1: Clean HERI student data and merge on zipcode information
*Section 2: Calculate distance to attended institution's state border and save heri_student, heri_zipcode, and heri_institution level files
*Section 3: Create heri_analysis.dta file at university-period-band-zipcode level
*Section 4: Merge on variables and generate additional variables that will be used in analysis
*Section 5: Apply filters to DROP observations and add on distance bands

*Input files: 1) TFS_KNFINAL2 2) zipDists_YEAR.dta 3) state_fips.dta 4)distBandsYEAR_0_30.dta, where YEAR is 1990, 2000, 2010 (3 separate files)
*--5) zip_gaz_2000.dta
*Output files created: 1) heri_student.dta 2) heri_zipcode.dta 3) heri_institution.dta 4) heri_analysis.dta

*Section 1: Clean HERI student data and merge on zipcode information
*-------------------------------------------------------------------------------
use "input/TFS_KNFINAL2.dta", clear //n=9,892,191 from years 1982-2011

duplicates tag subjid year, gen(dupTag)
drop if dupTag>0 //drop 608 students attending more than one institution
drop dupTag

gen zipcode_institution=string(ZIPCODE2000,"%05.0f") //give leading zeroes for zip codes with only four digits, use string for zips like "351HH"
replace zipcode_institution="" if ZIPCODE2000==. //n=49,318
label variable zipcode_institution "Institution zipcode, STRING value"
gen zipcode=string(homezip,"%05.0f") //give leading zeroes for zip codes with only four digits, use string for zips like "351HH"
label variable zipcode "Student's zipcode, STRING value"
replace zipcode="" if homezip==. //n=859,376
rename state state_institution

* keep only the variables that we plan to use in the analysis *
keep strat zipcode year acerecode subjid selectivity satv satm satw actcomp zipcode_institution IC* state_institution disthome

* now reshape to get in-state and out-of-state tuition in relevant year *
gen tuition_in=.
gen tuition_out=.

forvalues t = 1997/2011  {
replace tuition_in=IC`t'_IST if year==`t'
replace tuition_out=IC`t'_OST if year==`t'
}
drop IC*

* drop cases with missing geography (institution or home)*
drop if zipcode=="" //n=859,376
drop if zipcode_institution=="" //n=46,154, after first removing cases where (student) zipcode==""

gen zipYear=.
replace zipYear=1990 if year>1981&year<1991 //n=2,512,999 
replace zipYear=2000 if year>1990&year<2001 //n=2,896,520
replace zipYear=2010 if year>2000 //n=3,576,804; there should now be no observations where zipYear==.

*NOTE: strat is not consisent within university-year because some observations are missing, when others in same university-year cell are filled.
*----I create a new version of strat that replaces missing values with other value from university-year cell
replace strat=0 if strat==.
/*This code shows the issue
egen checkStrat=tag(acerecode year strat)
bysort acerecode year: egen countStrat=sum(checkStrat)
br acerecode year strat countStrat if countStrat==2&checkStrat
drop checkStrat countStrat
*/
bysort acerecode year: egen strat_t=max(strat)
replace strat_t=. if strat_t==0 //if every value of university-year cell is missing then assign missing, n=17039
label copy strat strat_t
label values strat_t strat_t
drop strat
rename strat_t strat

* create public/private measure *
gen private=1
replace private=0 if strat==1|strat==2|strat==3|strat==7|strat==8|strat==9|strat==10|strat==25|strat==26|strat==27|strat==28|strat==29|strat==34|strat==36|strat==40
replace private=. if strat==.
replace private=. if strat==99 //public: n=4,541,194; private: n=4,426,781

* create 2-year measure *
gen twoyear=0
replace twoyear=1 if strat>24&strat<34
replace twoyear=1 if strat==36
replace twoyear=1 if strat==37
replace twoyear=. if strat==.
replace twoyear=. if strat==99

* set out-of-state tuition equal to in-state if out-of-state missing & private *
replace tuition_out=tuition_in if private==1&tuition_out==.

*Create standardized SAT score (convert ACT, sum SAT V+M)
cap drop SAT_standard
do "code/return_SAT.do" //standardizes scores

save "temp/heri_temp.dta", replace //n=8,986,053

*Now add distance from zipcodes to state borders
foreach year in 1990 2000 2010 {
	use "input/zipDists_`year'.dta", clear
	duplicates tag zipcode, gen(dupTag)
	drop if dupTag>0 //drop all zipcodes found in more than one state
	drop dupTag
	sort zipcode
	save "temp/tempZip.dta", replace
	use "temp/heri_temp.dta", clear
	keep if zipYear==`year'
	sort zipcode
	merge zipcode using "temp/tempZip.dta", keep(stfipsdist_* zip_long zip_lat state_fips st_abbrev) //note: state_fips is GIS determined for 2010 Census
	rename state_fips stfips_student //student state fips
	rename st_abbrev state_student
	label variable state_student "Student's home state abbreviation"
	drop if _merge==2
	rename _merge zipDist_merge
	sort zipcode
	merge zipcode using "input/zip_gaz_2000.dta", keep(state_fips)
	rename state_fips stfips2000_student //this file has state_fips of PR, HI, and other non-continental; we can use this to look at unmatched HERI zips
	drop if _merge==2
	drop _merge
	save "temp/heri_temp_`year'.dta", replace
}

use "temp/heri_temp_1990.dta", clear //n=2,513,002 
append using "temp/heri_temp_2000.dta" //now n=5,409,255
append using "temp/heri_temp_2010.dta" //Note: older versions of code (101215) checked for duplicates (found none)
save "output/heri_student.dta", replace //n=8,986,059

*Now remove temp files
foreach filename in heri_temp.dta heri_temp_1990.dta heri_temp_2000.dta heri_temp_2010.dta tempZip.dta {
	rm "temp//`filename'"
}

*Section 2: Calculate distance to attended institution's state border and save heri_student, heri_zipcode, and heri_institution level files
*-----------------------------------------------------------------------------------------------------------------------
use "output/heri_student.dta", clear
gen st_abbrev=state_institution
sort st_abbrev
merge m:1 st_abbrev using "input/state_fips.dta", keepusing(state_fips)
drop if _merge==2 //n=2, American Samoa (60) and Marina Islands (69)
drop _merge st_abbrev
rename state_fips stfips_institution
label variable stfips_institution "State FIPS code of university"

*This shows state of unmatched zipcodes, majority from non-continental places
tab stfips2000_student if zipDist_merge==1 //AK(2), HI(15), PR(72)--these three places account for 61% of non-matching observations
drop if zipDist_merge==1 //we can't calculate distances for these zipcodes, drops n=457,062
drop zipDist_merge stfips2000_student
*Drop institutions in AK, PR, HI, as well as Guam (66) and Virgin Islands (78)
drop if inlist(state_institution, "AK","PR","HI") //drops n=1182
drop if inlist(stfips_institution, 66, 78) //drops n=28

gen dist_univ_border=.
label variable dist_univ_border "distance from student zip to university's state border"
foreach var of varlist stfipsdist_* {
	local distFips=real(subinstr("`var'","stfipsdist_","",1))
	replace dist_univ_border=`var' if `distFips'==stfips_institution
}
gen dummy=1
bysort acerecode year zipcode: egen enroll_zipYear=sum(dummy)
label variable enroll_zipYear "University's enrollment from zipcode in a year"
bysort acerecode year: egen enroll_year=sum(dummy)
label variable enroll_year "University's total enrollment in that year"
drop dummy
save "output/heri_student.dta", replace //n=8,527,787
table disthome, c(mean dist_univ_border min dist_univ_border max dist_univ_border) //note: our distance is in KM

*Now create institution file
*----------aggregate students to university-year level and calculate median test score by year (new 3/2/2016)
use "output/heri_student.dta", clear
gen studDummy=1
bysort acerecode year: egen SAT_std_med=median(SAT_standard)
gen above_med=(SAT_standard>SAT_std_med) if SAT_std_med!=.&SAT_standard!=.  //0: n=3,113,293; 1: n=2,808,707; missing: n=2606095
gen med_below=(SAT_standard<=SAT_std_med) if SAT_std_med!=.&SAT_standard!=. //includes students with median score (turns out to be many, n=311,204)
local studVars disthome dist_univ_border //we will take the mean of these in collapse
local instVars stfips_institution state_institution zipcode_institution zipYear selectivity tuition_in tuition_out strat private twoyear enroll_year SAT_std_med //these should be identical in collapse
collapse (sum) studCount=studDummy abvMed_year=above_med medBel_year=med_below (p50) satv_med=satv satm_med=satm satw_med=satw actcomp_med=actcomp (mean) `studVars', by(acerecode year `instVars') fast
duplicates report acerecode year //this should be zero, now n=16,781
count if studCount!=enroll_year //this should be zero
drop studCount
label variable abvMed_year "University's above median test score enrollment in year"
label variable medBel_year "University's below median test score enrollment in year (inclusive)"
order acerecode year state_institution zipcode_institution
gen state_fips=stfips_institution
gen zipcode=zipcode_institution
gen zipx_temp=.
gen zipy_temp=.
foreach year in 1990 2000 2010 {
	sort zipcode state_fips
	merge m:1 zipcode state_fips using "input/zipDists_`year'.dta", keepusing(zip_long zip_lat)
	drop if _merge==2
	replace zipx_temp=zip_long if zipYear==`year'
	replace zipy_temp=zip_lat if zipYear==`year'
	drop zip_long zip_lat _merge
}
duplicates report acerecode year //this should still be zero, with n=16,781 institutions
drop zipcode state_fips
*Now standardize by using the coordinates from the latest year available (note that our institution zipcode is probably from the latest year)
gen tempVar=(zipx_temp!=.)*zipYear
bysort acerecode: egen maxYear=max(tempVar)
gen zipx_max=zipx_temp if maxYear==zipYear //this is just one value, all other zipYears have missing values
gen zipy_max=zipy_temp if maxYear==zipYear
bysort zipcode: egen zipx_institution=max(zipx_max) //this assigns maximum to all years as long as maximum is not missing
bysort zipcode: egen zipy_institution=max(zipy_max)
drop zipx_temp zipy_temp tempVar maxYear zipx_max zipy_max
label variable zipx_institution "Institution zipcode longitude"
label variable zipy_institution "Institution zipcode latitude"
sort acerecode year
save "output/heri_institution.dta", replace //n=16,781

*----------Now aggregate students attending each university to zipcode (X students from zip Z go to inst U) by collapsing to acerecode-year-zipcode level
use "output/heri_student.dta", clear
*First, merge on institution median scores so that we can aggregate above median students to zipcode
sort acerecode year
merge m:1 acerecode year using "output/heri_institution.dta", keepusing(SAT_std_med) //Note: SAT_std_med missing for n=983,886 in post-merge file; also no need to merge, could calc directly
drop _merge // _merge should equal 3 for all 8,527,787 obs
gen above_med=(SAT_standard>SAT_std_med) if SAT_std_med!=.&SAT_standard!=.  //0: n=3,113,264; 1: n=2,808,692; missing: n=2,605,831
gen med_below=(SAT_standard<=SAT_std_med) if SAT_std_med!=.&SAT_standard!=. //includes students with median score (turns out to be many, n=311,204)

local studVars satv satm satw actcomp disthome SAT_standard //we will take the mean of these in collapse
local instVars stfips_institution state_institution zipcode_institution zipYear selectivity tuition_in tuition_out strat private twoyear enroll_year SAT_std_med //should be identical in collapse
local zipVars zip_long zip_lat dist_univ_border stfips_student state_student enroll_zipYear
gen dummy=1
collapse (sum) checkCount=dummy aboveMed_zipYear=above_med medBelow_zipYear=med_below (mean) `studVars', by(acerecode year zipcode `instVars' `zipVars') fast //note: fast speeds up collapse, but collapse command cannot be stopped (must reload)
duplicates report acerecode year zipcode //this should be zero, n=4,160,763 after collapse
count if checkCount!=enroll_zipYear //this should be zero
drop checkCount
order acerecode year state_institution state_student zipcode dist_univ_border
sort acerecode year zipcode
save "output/heri_zipcode.dta", replace //n=4,160,763

*Section 3: Create analysis file at university-period-band-zipcode level
*---We want to merge on ALL zipcodes within the distance bands of each university, for each period, regardless of whether there are any students from the zipcode attending the university
*-----------------------------------------------------------------------------------------------------------------------
use "output/heri_institution.dta", clear
duplicates drop acerecode, force //drops 15,361 obs, now n=1,420
keep acerecode stfips_institution //only want to keep time-invariant vars--will merge on rest later
rename stfips_institution hSt_fips
sort hSt_fips
save "output/uniqUniv.dta", replace //n=1,420 unique universities across all years
*Create a file with all possible border zipcodes FOR EACH year range (zipYear range)
local expand_1990=9 //1982-1990: 9 years
local expand_2000=10 //1991-2000: 10 years
local expand_2010=11 //2001-2011: 11 years
local startYear=1981 //this local is for relabeling the years after the expansion command
foreach year in 1990 2000 2010 {
	use "output/distBands`year'_0_30.dta", clear //file with all zipcodes and distance to any border state within 30 km
	drop if hSt_fips==bSt_fips //drop all distance to own state border obs, due to inconsistencies (rivers, etc...)
	bysort zipcode: egen minDist=min(borderDist_)
	keep if borderDist_==minDist //there should now be zero duplicates in zipcode
	sort hSt_fips
	save "temp/distBands_toMerge.dta", replace
	use "output/uniqUniv.dta", clear //I now merge on all the zipcodes within the specified distance bands onto the unique universities
	joinby hSt_fips using "temp/distBands_toMerge.dta" //These are the INSTATE zipcodes, total across all universities: n=395,897
	gen inState=1
	sort acerecode borderDist_
	save "temp/inState_zips.dta", replace //I will combine with out-of-state through an append
	*Now sort distBands file for merging as out-of-state zipcodes
	use "temp/distBands_toMerge.dta", clear
	sort bSt_fips
	save "temp/distBands_toMerge.dta", replace
	*Join out-of-state zipcodes to university file
	use "output/uniqUniv.dta", clear //I now merge on all the zipcodes within the specified distance bands onto the unique universities
	rename hSt_fips bSt_fips
	joinby bSt_fips using "temp/distBands_toMerge.dta" //These are the OUT-OF-STATE zipcodes, total across all universities: n=369,154
	gen inState=0
	append using "temp/inState_zips.dta" //append IN-STATE zipcodes to OUT-OF-STATE file; zipcodes are for same year range (1990, 2000, or 2010)
	sort acerecode borderDist_
	gen fakeCl=1
	expandcl `expand_`year'', generate(year) cluster(fakeCl) //this expands the dataset to accomodate years in range
	replace year=year+`startYear' 
	local startYear=`year' //1981, 1990, 1999 for three year sets
	save "temp/temp_`year'.dta", replace
}
*Current file should be temp_2010.dta, append other two files, n=9,320,421
append using "temp/temp_2000.dta" //n=17,767,981
append using "temp/temp_1990.dta" //n=24,653,440
tab year if acerecode==2 //should be 490, 522, 538 for each year range
sort acerecode year zipcode
display "Number of records should be n=24,653,440; it is " as result _N
save "temp/distBands_frame.dta", replace //n=24,653,440, this is just the distance bands frame, I then merge on all the student data

foreach year in 1990 2000 2010 {
	rm "temp/temp_`year'.dta"
}
rm "temp/distBands_toMerge.dta"
rm "temp/inState_zips.dta"

*Now create the analysis file
*-----------------------------------------------------------------
use "temp/distBands_frame.dta", clear 
*First merge on institution variables
local instVars stfips_institution state_institution zipcode_institution zipYear selectivity tuition_in tuition_out strat private twoyear enroll_year ///
	zipx_institution zipy_institution SAT_std_med abvMed_year medBel_year

merge m:1 acerecode year using "output/heri_institution.dta", keepusing(`instVars')
gen instYearData=(_merge==3) //indicator for whether institution was in survey in a given year. In survey: n=10,477,511 (42.5%), NOT in survey: n=14,175,929 (57.5%)
label variable instYearData "Equal to one if institution was in survey in that year"
drop _merge
*Check to make sure INSTITUTION state fips codes match
gen checkStFips=.
replace checkStFips=(stfips_institution==hSt_fips) if inState==1&instYearData
replace checkStFips=(stfips_institution==bSt_fips) if inState==0&instYearData
tab checkStFips //these should all be 1, n=10,477,511
drop checkStFips
*Now merged on all students by zipcode. Note: if we want to only merge on students by some filter then we need to start with heri_student.dta
merge m:1 acerecode year zipcode using "output/heri_zipcode.dta", keepusing(enroll_zipYear aboveMed_zipYear medBelow_zipYear dist_univ_border stfips_student SAT_std_med) //only need enroll_zipYear, others are just for checking
*New file:
*1) merge==3: there are 872,490 (3.12%) border zipcodes that match the HERI data, meaning a university has at least one student from the zipcode in that year
*2) merge==1: there are 23,780,950 (85.11%) border zipcodes that do NOT match the HERI data, meaning university has no students from zipcode-year.
*---Of the 23,780,950 unmatched, TBD are obs when university was not covered by HERI in that year. After dropping these we will have added TBD zeros.
*3) merge==2: there are 3,288,273 (11.7%) HERI zipcodes not in our border file; these are students from zipcodes outside of the 30km bandwidth
*DON'T DELETE _merge; used in addVars.do
save "output/heri_analysis.dta", replace //n=27,941,713
rm "temp/distBands_frame.dta"

*Check to make sure STUDENT state fips codes match
gen checkStFips=(hSt_fips==stfips_student)
tab checkStFips if _merge==3 //these should all be 1's, n=872,490
drop checkStFips stfips_student //stfips_student is only filled out for merged values so use hSt_fips
rename hSt_fips stfips_student
label variable stfips_student "State FIPS code for student"
rename hSt_abbrev state_student
label variable state_student "Student's home state abbreviation"

replace enroll_zipYear=0 if enroll_zipYear==.
bysort acerecode year: egen tot_enroll=sum(enroll_zipYear) //this is the total enrollment, equal to enroll_year when enroll_year is not missing
count if (tot_enroll!=enroll_year)&enroll_year!=. //this should be zero
drop if _merge==2 //drop n=3,288,273
count if tot_enroll==0 //n=14,175,929--this should be equal to number of obs when institution was NOT in survey for that year
drop tot_enroll _merge //tot_enroll is now just a duplicate of enroll_year, but enroll_year is filled for all observations

egen uniq_univYear=tag(acerecode year)
table year, c(sum uniq_univYear) //this should be 1,420 for all 30 years
drop if instYearData==0 //this drops all observations for universities not covered in that year (14,175,929 dropped)
table year, c(sum uniq_univYear) //note that enroll_year cannot have missing values
drop instYearData uniq_univYear

*Check to make sure distances match. NOTE: border distances are calculated EXCLUDING distance to own-border, therefore some will not match
gen diff=abs(dist_univ_border-borderDist_) if dist_univ_border!=.
sum diff, detail //this shouldn't be too large since it only reflects own border differences, I find max of 30km
tab inState if (dist_univ_border!=borderDist_)&(dist_univ_border!=.) //these should be all 1's, n=588,156
drop diff dist_univ_border

gen perEnroll_year=enroll_zipYear/enroll_year //there should be no missing values
label variable enroll_zipYear "Number of students from zipcode attending university in year t"
label variable enroll_year "Total number students attending university in HERI data (all zipcodes, regardless of distance)"
label variable perEnroll_year "Percentage of annual univ enrollment zipcode"
*Rename variables and drop unnecessary variables
rename bSt_abbrev state_border
label variable state_border "Border state abbreviation"
drop zipNum fakeCl minDist
rename zip_long zipx_student
rename zip_lat zipy_student
label variable zipcode "Student's zipcode"
label variable borderDist_ "Distance from stud zip to border"
save "output/heri_analysis.dta", replace //n=10,477,511

*Section 4: Merge on additional variables, create new variables that will be used in analysis
*--------------------------------------------------------------------------------------

*Get distance from INSTITUTION zipcode to border
use "output/distBands2010_0_30.dta", clear //file with all zipcodes and distance to any border state within 30 km
drop if hSt_fips==bSt_fips //drop all distance to own state border obs, due to inconsistencies (rivers, etc...), drops 14,671 obs
rename borderDist_ inst_borderDist
*rename bSt_fips stfips_border //to match heri_analysis.dta
rename zipcode zipcode_institution //to match heri_analysis.dta
sort zipcode bSt_fips
save "temp/inst_borderDist.dta", replace
*--merging back on to main analysis file
use "output/heri_analysis.dta", clear
rename bSt_fips stfips_border
label variable stfips_border "FIPS code of border state (relative to stud zip)"
gen bSt_fips=stfips_border if inState==1  // if in-state then use border-state fips
replace bSt_fips=stfips_student if inState==0 //if out-of-state then use student's state-fips
merge m:1 zipcode_institution bSt_fips using "temp/inst_borderDist.dta", keepusing(inst_borderDist)
drop if _merge==2 //these are zipcodes that don't contain a university, only 0.11%, or n=12,002 
*Note: 13% of observations are within 30k of a border; however, only 7.5% of univ-borderStates are within 30k
drop _merge
label variable inst_borderDist "Dist univ zipcode to each border (w/in 30k)"

*Merge on tuition reciprocity indicators----------------------------------------
gen st=state_institution
merge m:1 st using "input/tuition_exchanges.dta", keep(startyearMSEP endyearMSEP startyearNEBHE endyearNEBHE startyearSREB endyearSREB startyearWUE endyearWUE)
drop if _merge==2 //this is AK and HI; _merge==1 for DC, FL, IA, NJ, NY, OH, PA, TX
foreach grp in MSEP NEBHE SREB WUE {
	gen univ_`grp'=0
	replace univ_`grp'=1 if (startyear`grp'!=.)&(year>=startyear`grp')&(year<=endyear`grp'|endyear`grp'==.)
}
drop st _merge startyearMSEP endyearMSEP startyearNEBHE endyearNEBHE startyearSREB endyearSREB startyearWUE endyearWUE
*Now merge on student state info
gen st=state_student
merge m:1 st using "input/tuition_exchanges.dta", keepusing(startyearMSEP endyearMSEP startyearNEBHE endyearNEBHE startyearSREB endyearSREB startyearWUE endyearWUE)
drop if _merge==2 //this is AK and HI; _merge==1 for DC, FL, IA, NJ, NY, OH, PA, TX
foreach grp in MSEP NEBHE SREB WUE {
	gen stud_`grp'=0
	replace stud_`grp'=1 if (startyear`grp'!=.)&(year>=startyear`grp')&(year<=endyear`grp'|endyear`grp'==.)
}
drop st _merge startyearMSEP endyearMSEP startyearNEBHE endyearNEBHE startyearSREB endyearSREB startyearWUE endyearWUE
save "output/heri_analysis.dta", replace //n=10,477,511

*Generate additional variables--------------------------------------------------
*Calculate distance between student zip and university zip, requires geodist.ado (findit geodist)
geodist zipy_student zipx_student zipy_institution zipx_institution, gen(dist_to_univ) sphere
count if inState==0&dist_to_univ<borderDist_ //this should be 0. For in-state students (in our border zipcodes) about 2% live closer to the university than to the border.
label variable dist_to_univ "Distance from student's home zipcode to university zipcode in KM"

*Create distance variable (negative for out-of-state)
gen distance=borderDist_ if inState==1
replace distance=-1*borderDist_ if inState==0
gen inState_dist=inState*distance

*Create tuition reciprocity indicator. Reciprocity borders are: MN-SD (27_46), MN-ND (27_38), and MN-WI (27_55),
gen reciprocityBorder=0
replace reciprocityBorder=1 if border_=="27_46"|border_=="27_38"|border_=="27_55"

*Adjust tuition based on CPI
gen cpi=160.5 if year==1997
replace cpi=163.0 if year==1998
replace cpi=166.6 if year==1999
replace cpi=172.2 if year==2000
replace cpi=177.1 if year==2001
replace cpi=179.9 if year==2002
replace cpi=184.0 if year==2003
replace cpi=188.9 if year==2004
replace cpi=195.3 if year==2005
replace cpi=201.6 if year==2006
replace cpi=207.3 if year==2007
replace cpi=215.3 if year==2008
replace cpi=214.5 if year==2009
replace cpi=218.1 if year==2010
replace cpi=224.9 if year==2011

* create real tuition (in thousands of 2011 dollars) *
gen tuition_in_real=(tuition_in/1000)*(224.9/cpi)
gen tuition_out_real=(tuition_out/1000)*(224.9/cpi)

* generate effective tuition depending upon side of border *
gen tuition=tuition_in_real if distance>=0
replace tuition=tuition_out_real if distance<0
* account for reciprocity *
replace tuition=tuition_in_real if distance<0&reciprocityBorder==1
gen tuition_dist=tuition*distance

order acerecode year state_institution state_student inState zipcode borderDist_ border_ dist_to_univ enroll_zipYear enroll_year perEnroll_year stfips_institution zipcode_institution selectivity ///
 strat private twoyear tuition_in tuition_out stfips_student zipx_student zipy_student zipYear
sort acerecode year zipcode
save "output/heri_analysis.dta", replace //n=10,477,511

*Section 5: Apply filters to DROP observations and add on distance bands
*-------------------------------------------------------------------------------
use "output/heri_analysis.dta", clear
bysort zipcode year: egen total_zipYear=sum(enroll_zipYear)
label variable total_zipYear "Total enrollment across all universities from a zipcode in a year"
count if total_zipYear==0 //n=2,817,551 :about 27% of observations
drop if total_zipYear==0 //Filter #1: the dataset now has n=7,659,960 observations
egen uniqUnivYr=tag(acerecode year)
sum enroll_year if uniqUnivYr, detail
drop if enroll_year<100 //Filter #2: drops university-year cells with fewer than 100 total respondents
*--removes 701,053 obs and ABOUT 1653 university-years
drop if twoyear==1 //Filter #3: drops 531,509

*Create distance bands
*This file has bands in increments of 1km. The following code can change the band
gen borderBand=""
gen bandDistance=.
local bandIncr=2
forvalues bmax=`bandIncr'(`bandIncr')30 {
	local bmin=`bmax'-`bandIncr'
	replace borderBand=string(stfips_student)+"_"+string(stfips_border)+"_b"+string(`bmin')+"_"+string(`bmax') if borderBand==""&`bmin'<=bandMin&bandMax<=`bmax'
	replace bandDistance=(`bmax'+`bmin')/2 if bandDistance==.&`bmin'<=bandMin&bandMax<=`bmax'
}
gen distance_b=bandDistance if inState==1
replace distance_b=-1*bandDistance if inState==0
label variable distance_b "distance"
gen inState_dist_b=inState*distance_b
label variable inState_dist_b "in-state*distance"
label variable inState "in-state"
egen uniqUYrBand=tag(acerecode year borderBand) //n=1,443,411

*Create FULL enrollment dependent variables
bysort acerecode borderBand year: egen enroll_bandYear=sum(enroll_zipYear)
label variable enroll_bandYear "University's enrollment from border band in year"
bysort borderBand year: egen total_bandYear=sum(enroll_zipYear)
label variable total_bandYear "Total enrollment across all universities for band in year"
count if total_bandYear==0 //n=11,293, Distance bands with zero students across all universities in a year; exclude these in regressions
gen lnN_bandYear=ln(enroll_bandYear)
label variable lnN_bandYear "ln(enroll)"
gen lnN_bandYear_p1=ln(enroll_bandYear+1)
label variable lnN_bandYear_p1 "ln(enroll+1)"

*Now create ABOVE-MEDIAN enrollment dependent variables
*Note: we are currently not applying any additional filters to above-median analysis
bysort acerecode borderBand year: egen abvMed_bandYear=sum(aboveMed_zipYear)
label variable abvMed_bandYear "University's above-median-score enrollment from border band in year"
bysort borderBand year: egen abvTotal_bandYear=sum(aboveMed_zipYear)
label variable abvTotal_bandYear "Total above-median students across all universities in band in year"
count if abvTotal_bandYear==0 //n=875,107 Distance bands with zero students across all universities in a year; exclude these in regressions
gen lnAbv_bandYear=ln(abvMed_bandYear)
label variable lnAbv_bandYear "ln(abv_enroll)"
gen lnAbv_bandYear_p1=ln(abvMed_bandYear+1)
label variable lnAbv_bandYear_p1 "ln(abv_enroll+1)"

*Create distance increments. Note: distance variable (negative for out-of-state) should already be in heri_analysis.dta (create_analysis_file.do)
egen distance_coarse = cut(distance), at(-32(2)32) //only have border zipcodes within 30km
*Create additional variables for analysis
gen lnNzct=log(enroll_zipYear+1)
egen uniqUniv=tag(acerecode)

*Create grouping variables
egen zipcodeYear=group(zipcode year) //note: there are 184,098 unique zipcode years, which means many zipcodes correspond to just one university in a given year
egen univYear=group(acerecode year) //there are 14,135 unique university-years
egen stateYear=group(stfips_student year) //there are 1,408 unique state-years
egen bandYear=group(borderBand year) //n=54,032 unique band-years
egen univState=group(acerecode stfips_student) //university and student state, n=6570 unique university-student_states
egen univSt_studSt=group(stfips_institution stfips_student) //university state and student state, n=263
egen univZip=group(acerecode zipcode) //n=654,151
egen univBand=group(acerecode borderBand) //n=136,763
bysort acerecode border_ year: egen enroll_borderYear=sum(enroll_zipYear)
bysort borderBand year: egen totEnroll_bandYear=sum(enroll_zipYear)
sum enroll_borderYear, detail

count if private==0&year>1996&uniqUYrBand
display "There are " as result r(N) " acerecode-year-border bands using bandwidth `bandIncr' for public, year>1996"
note: this dataset is at the acerecode-year-zipcode level
note: it only includes zipcodes within 30k of the border
save "output/heri_analysis.dta", replace //this file is over 2gb!, n=6,427,398
