*return_distBand: should make this a function with parameters: 1) zipdist file 2) outfile name 3) band min 4) band max
*This program requires 4 parameters as globals: distMin, distMax, zipDistFile, outBandsFile:
* 1) minimum distance for band, Ex: global distMin=0
* 2) maximum distance for band, Ex: global distMax=30
* 3) name of zip distance file, Ex: global zipDistFile="zipDists_1990.dta"
* 4) name of file to create, 	Ex: global outBandsFile="zipBands_${distMin}_${distMax}.dta"

*Notes:
*1) in this definition of borders I include the distance from zipcode to its own state border; this is labeled "stfips_stfips", such as 44_44 for RI
*2) it's possible to have only one border; for example, an RI zipcode may be near the ocean
*3) this definition of "borders" is not actually a border but only depends on the distance band
*-----if distance from zip i to state j is distMin<dist_ij<distMax then it is a border, whether or not there are other states in between
*4) rural zipcodes can be very large, leading to surprising results
*--Ex: NM zip 87420 corresponds to "Four Corners" point (UT,CO,NM,AZ) but the centroid is 47km from UT and 37km from CO in 1990

use ${zipDistFile}, clear

gen bandMin=${distMin}
gen bandMax=${distMax}

*First count the number of borders for each zipcode
gen numBorders=0
foreach var of varlist stfipsdist_* {
	replace numBorders=numBorders+1 if (${distMin}<=`var')&(`var'<${distMax})
}
sum numBorders
local maxBorders=r(max)
*Create variables for holding border information
forvalues currBorder=1(1)`maxBorders' {
	gen border_`currBorder'=""
	gen borderDist_`currBorder'=.
	gen double borderX_`currBorder'=.
	gen double borderY_`currBorder'=.
}
*Now I iterate through every state and save border name and distance if zipcode is within specified distance band
*---a zipcode may be within distance band of multiple states; I therefore have multiple borders and order them by state_fips code
gen borderCtr=0
gen isBorder=.
order stfipsdist*, sequential //this is so border numbers are always increasing in state_fips code (border_1 is border with lowest state_fips)
foreach var of varlist stfipsdist_* {
	local currState=real(subinstr("`var'","stfipsdist_","",1))
	local currStateSt=subinstr("`var'","stfipsdist_","",1) //this deals with "01" vs "1" issue
	replace isBorder=(${distMin}<=`var')&(`var'<${distMax})
	replace borderCtr=borderCtr+1 if isBorder
	forvalues currBorder=1(1)`maxBorders' {
		replace border_`currBorder'="`currState'_"+string(state_fips) if isBorder&(borderCtr==`currBorder')&(`currState'<=state_fips) //allows for dist to own state border
		replace border_`currBorder'=string(state_fips)+"_`currState'" if isBorder&(borderCtr==`currBorder')&(`currState'>state_fips)
		replace borderDist_`currBorder'=`var' if isBorder&(borderCtr==`currBorder')
		replace borderX_`currBorder'=stfipsx_`currStateSt' if isBorder&(borderCtr==`currBorder')
		replace borderY_`currBorder'=stfipsy_`currStateSt' if isBorder&(borderCtr==`currBorder')
	}
}
*br st_abbrev zipcode numBorders borderCtr border_* borderDist_* if numBorders>0 //used for checking
*I now reshape the file into long format with unit of observation: zipcode-border, Ex: 02906-Border1,02906-Border2
drop if numBorders==0
keep zipcode zipNum state_fips zip_long zip_lat st_abbrev numBorders border_* borderDist_* borderX_* borderY_* bandMin bandMax
reshape long border_ borderDist_ borderX_ borderY_, i(zipNum state_fips st_abbrev zip_long zip_lat numBorders bandMin bandMax) j(borderNum)
drop if borderDist_==.
sort zipcode
save ${outBandsFile}, replace
