#Calcuate distance from ZCTA centroids to state borders
#Note: The most current version of this file is always called "calc_zip_dists.R" (no version number)
#1) The zipcode data comes from the US Gazetteer; it's GCS is NAD 83 (see FAQ: https://www.census.gov/geo/maps-data/data/geocoder.html)
#2) The states shapefile comes from the US Census Tiger Files (https://www.census.gov/cgi-bin/geo/shapefiles2010/layers.cgi)
#----------This file is also NAD 83. I am using the 2010 Census shape files for all zipcode years (I think this is OK--states don't change).
#3)
#4)

#Part1: bring data into R, convert to ppp and psp; note that data is in GCS
#setwd("D:/misc/aej_replication_LOCAL/create_zipcode_dists")
#NOTE: need to be in root of "create_zipcode_dists" directory

library(maptools)
library(spdep)
install.packages(spatstat)
library(spatstat)
install.packages(sp)
library(sp)
library(rgdal)

#First read in state boundaries file
#1) I use a detail boundary file that includes water area for assigning state_fips codes to zipcodes: allStatesPoly
allStatesPoly<-readShapePoly("input/states_with_WATER_2010/tl_2010_us_state10.shp") #there are 50 states, plus DC and PR (52 features total)
#2) I use a simpler "cartographic boundary file" for calculating distances that excludes water areas
contStatesPoly<-readShapePoly("input/states_LAND_ONLY_2010/gz_2010_us_040_00_500k.shp") #there are 50 states, plus DC and PR (52 features total)

#Create a new NON-factor variable (otherwise factor indexes may be used instead of levels)
allStatesPoly$state_fips<-as.numeric(levels(allStatesPoly$STATEFP10)[allStatesPoly$STATEFP10])
contStatesPoly$state_fips<-as.numeric(levels(contStatesPoly$STATE)[contStatesPoly$STATE])
#Restrict to continental states only
nonContStNames<-c("Alaska","Puerto Rico","Hawaii")
#I used continental states for distance calculations and mapping
contStatesPoly<-contStatesPoly[!(contStatesPoly$NAME%in%nonContStNames),] #there are 49 features: 48 continental states plus DC
#Now create a list with windows of all the states. I do this so that I can convert these windows into points
states <- slot(contStatesPoly, "polygons")
states2 <- lapply(states, function(x) {SpatialPolygons(list(x))})
stateList <- lapply(states2, as.owin)
#Additional variables used in loop
stateNames<-as.character(levels(contStatesPoly$NAME)[contStatesPoly$NAME])
numStates<-length(stateList) #49: 48 continental states plus DC
numPts<-2500 #I discretize border into a number of points equal to numPts
yearList<-c("1990","2000","2010","2012","2013","2014")
#For testing, remove below
yearList<-c("1990","2010","2000","2012","2013","2014")
for (currYear in yearList) {
    year=currYear
    zipfile=paste("output/zip_gaz_",year,".csv",sep="")
    #zip data files all have these columns: zipcode, zip_lat, zip_long
    zipData<-read.table(zipfile,header=T,sep=",",stringsAsFactors =FALSE)
    #Convert zipcode data into PPP object; this is what I will use for calculating distances
    zipPoints<-ppp(zipData$zip_long,zipData$zip_lat,c(min(zipData$zip_long)-1,max(zipData$zip_long)+1),c(min(zipData$zip_lat)-1,max(zipData$zip_lat)+1))

    #Convert zipcode latitutde and longitude into SpatialPoints object. I only use this for doing the spatial overlay to assign states.
    zipSpatialPoints<-SpatialPoints(cbind(zipData$zip_long,zipData$zip_lat))

    #For the overlay I used the COMPLETE state file so that I can label zipcodes in AK, HI, and PR and for accuracy
    zipStateData<-over(zipSpatialPoints,allStatesPoly) #this overlays states data onto zipcodes, using a spatial merge (point in polygon)

    #Create map of zip codes in that year
    mapfile=paste("output/",year,"_zips.pdf",sep="")
    pdf(mapfile,width=17.5, height=9.69)
    plot(contStatesPoly)
    points(zipPoints,col="blue")
    mapTitle=paste("Zip Code Tract Area centroids in ",year,sep="")
    title(main = mapTitle)
    dev.off()

    #Set up data file to store zip-to-state distances
    numInitVars=5
    numStateVars=3
    distData<-array(,c(length(zipData$zip_long),numInitVars+numStates*numStateVars))
    distData[,1]<-zipData$state_fips
    distData[,2]<-zipData$zipcode
    distData[,3]<-zipData$zip_long
    distData[,4]<-zipData$zip_lat
    distData[,5]<-zipStateData$state_fips #this is the state assigned through the overlay
    #Name of columns in output file
    stFIPNames<-c("state_fips","zipcode","zip_long","zip_lat","GIS_stFips")

    #This is the part that takes a long time: roughly one hour per year
    system.time(
    for (j in 1:length(stateList)) {
        tempWin<-as.owin(stateList[[j]])
        tempPSP<-as.psp(tempWin)
        tempPPP<-pointsOnLines(tempPSP,np=numPts)
        tempPts<-array(c(tempPPP$x,tempPPP$y),c(length(tempPPP$x),2))
        for (i in 1:length(zipData$zip_long)) {
            tempPt<-c(zipData$zip_long[i],zipData$zip_lat[i])
            distVec <- spDistsN1(tempPts, tempPt, longlat = TRUE) #returns KM
            minDist <- min(distVec)
            closestPt <- which.min(distVec)
            distData[i,numInitVars+(j-1)*numStateVars+1]<-minDist
            distData[i,numInitVars+(j-1)*numStateVars+2]<-tempPPP$x[closestPt]
            distData[i,numInitVars+(j-1)*numStateVars+3]<-tempPPP$y[closestPt] #when j=numStates this should be last column
        }
        tempName1=paste("stFIPsDist_",contStatesPoly$state_fips[j],sep="")
        tempName2=paste("stFIPsX_",contStatesPoly$state_fips[j],sep="")
        tempName3=paste("stFIPsY_",contStatesPoly$state_fips[j],sep="")
        stFIPNames=c(stFIPNames,tempName1,tempName2,tempName3)
    }
    )

    outFileName=paste("output/zipDists_",year,".csv",sep="")
    write.table(distData, file = outFileName, sep = ",", col.names=stFIPNames,row.names=FALSE,na="")
} #End year loop
